==> ejc-ztpccom-impl-3.0.0-20230715.093316-38-sources.jar: com/ejianc/business/pub/vo/BillCodeRuleAttrVO.java <==
package com.ejianc.business.pub.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 取号编码规则子元素
 * 
 * @author generator
 * 
 */
public class BillCodeRuleAttrVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long ruleId; // 主表id
    private Integer elemOrder; // 序号
    private Long ruleElem; // 元素
    private String ruleElemCode; // 元素字段code
    private String ruleElemType; // 元素类型
    private String elemValue; // 属性值
    private Integer startNum; // 流水起始号
    private Integer endNum; // 流水结束号
    private Integer elemLength; // 长度


    public Long getRuleId() {
        return ruleId;
    }

    public void setRuleId(Long ruleId) {
        this.ruleId = ruleId;
    }

    public Integer getElemOrder() {
        return elemOrder;
    }

    public void setElemOrder(Integer elemOrder) {
        this.elemOrder = elemOrder;
    }

    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getRuleElem() {
        return ruleElem;
    }
    @ReferDeserialTransfer
    public void setRuleElem(Long ruleElem) {
        this.ruleElem = ruleElem;
    }

    public String getRuleElemType() {
        return ruleElemType;
    }

    public void setRuleElemType(String ruleElemType) {
        this.ruleElemType = ruleElemType;
    }
    public String getElemValue() {
        return elemValue;
    }

    public void setElemValue(String elemValue) {
        this.elemValue = elemValue;
    }
    public Integer getStartNum() {
        return startNum;
    }

    public void setStartNum(Integer startNum) {
        this.startNum = startNum;
    }
    public Integer getEndNum() {
        return endNum;
    }

    public void setEndNum(Integer endNum) {
        this.endNum = endNum;
    }
    public Integer getElemLength() {
        return elemLength;
    }

    public void setElemLength(Integer elemLength) {
        this.elemLength = elemLength;
    }

    public String getRuleElemCode() {
        return ruleElemCode;
    }

    public void setRuleElemCode(String ruleElemCode) {
        this.ruleElemCode = ruleElemCode;
    }
}

==> ejc-ztpccom-impl-3.0.0-20240325.072041-93-sources.jar: com/ejianc/business/pub/vo/BillCodeRuleAttrVO.java <==
package com.ejianc.business.pub.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 取号编码规则子元素
 * 
 * @author generator
 * 
 */
public class BillCodeRuleAttrVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long ruleId; // 主表id
    private Integer elemOrder; // 序号
    private Long ruleElem; // 元素
    private String ruleElemCode; // 元素字段code
    private String ruleElemType; // 元素类型
    private String elemValue; // 属性值
    private Integer startNum; // 流水起始号
    private Integer endNum; // 流水结束号
    private Integer elemLength; // 长度
    private String memo; // 备注


    public Long getRuleId() {
        return ruleId;
    }

    public void setRuleId(Long ruleId) {
        this.ruleId = ruleId;
    }

    public Integer getElemOrder() {
        return elemOrder;
    }

    public void setElemOrder(Integer elemOrder) {
        this.elemOrder = elemOrder;
    }

    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getRuleElem() {
        return ruleElem;
    }
    @ReferDeserialTransfer
    public void setRuleElem(Long ruleElem) {
        this.ruleElem = ruleElem;
    }

    public String getRuleElemType() {
        return ruleElemType;
    }

    public void setRuleElemType(String ruleElemType) {
        this.ruleElemType = ruleElemType;
    }
    public String getElemValue() {
        return elemValue;
    }

    public void setElemValue(String elemValue) {
        this.elemValue = elemValue;
    }
    public Integer getStartNum() {
        return startNum;
    }

    public void setStartNum(Integer startNum) {
        this.startNum = startNum;
    }
    public Integer getEndNum() {
        return endNum;
    }

    public void setEndNum(Integer endNum) {
        this.endNum = endNum;
    }
    public Integer getElemLength() {
        return elemLength;
    }

    public void setElemLength(Integer elemLength) {
        this.elemLength = elemLength;
    }

    public String getRuleElemCode() {
        return ruleElemCode;
    }

    public void setRuleElemCode(String ruleElemCode) {
        this.ruleElemCode = ruleElemCode;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}
